==> zio-aws-databasemigration_2.13-5.17.102.7-sources.jar: zio/aws/databasemigration/model/DeleteEndpointResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class DeleteEndpointResponse(
    endpoint: Option[zio.aws.databasemigration.model.Endpoint] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse = {
    import DeleteEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
      .builder()
      .optionallyWith(endpoint.map(value => value.buildAwsValue()))(_.endpoint)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.DeleteEndpointResponse.ReadOnly =
    zio.aws.databasemigration.model.DeleteEndpointResponse.wrap(buildAwsValue())
}
object DeleteEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databasemigration.model.DeleteEndpointResponse =
      zio.aws.databasemigration.model
        .DeleteEndpointResponse(endpoint.map(value => value.asEditable))
    def endpoint: Option[zio.aws.databasemigration.model.Endpoint.ReadOnly]
    def getEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.Endpoint.ReadOnly
    ] = AwsError.unwrapOptionField("endpoint", endpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
  ) extends zio.aws.databasemigration.model.DeleteEndpointResponse.ReadOnly {
    override val endpoint
        : Option[zio.aws.databasemigration.model.Endpoint.ReadOnly] = scala
      .Option(impl.endpoint())
      .map(value => zio.aws.databasemigration.model.Endpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
  ): zio.aws.databasemigration.model.DeleteEndpointResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-databasemigration_2.13-5.20.7.1-sources.jar: zio/aws/databasemigration/model/DeleteEndpointResponse.scala <==
package zio.aws.databasemigration.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class DeleteEndpointResponse(
    endpoint: Optional[zio.aws.databasemigration.model.Endpoint] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse = {
    import DeleteEndpointResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
      .builder()
      .optionallyWith(endpoint.map(value => value.buildAwsValue()))(_.endpoint)
      .build()
  }
  def asReadOnly
      : zio.aws.databasemigration.model.DeleteEndpointResponse.ReadOnly =
    zio.aws.databasemigration.model.DeleteEndpointResponse.wrap(buildAwsValue())
}
object DeleteEndpointResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.databasemigration.model.DeleteEndpointResponse =
      zio.aws.databasemigration.model
        .DeleteEndpointResponse(endpoint.map(value => value.asEditable))
    def endpoint: Optional[zio.aws.databasemigration.model.Endpoint.ReadOnly]
    def getEndpoint: ZIO[
      Any,
      AwsError,
      zio.aws.databasemigration.model.Endpoint.ReadOnly
    ] = AwsError.unwrapOptionField("endpoint", endpoint)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
  ) extends zio.aws.databasemigration.model.DeleteEndpointResponse.ReadOnly {
    override val endpoint
        : Optional[zio.aws.databasemigration.model.Endpoint.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.endpoint())
        .map(value => zio.aws.databasemigration.model.Endpoint.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.databasemigration.model.DeleteEndpointResponse
  ): zio.aws.databasemigration.model.DeleteEndpointResponse.ReadOnly =
    new Wrapper(impl)
}
